closeSession method

  1. @override
Future<void> closeSession(
  1. int sessionId
)
override

Implementation

@override
Future<void> closeSession(int sessionId) async {
  calls.add('closeSession');
  // Tolerates an unknown id the way a real host does: closing twice, or
  // closing after the model went away, must not throw.
  session(sessionId)?.closed = true;
  closedIds.add(sessionId);
}