countTokensError property

Object? countTokensError
getter/setter pair

Thrown by countTokens when set. Use LocalAiTokenizerUnavailable to model a host with no tokenizer, or any other error to model a broken channel.

Implementation

Object? countTokensError;