lastOverrides property
Sampling the most recent generate call on this session carried, or null when it inherited the session's own.
Implementation
LocalAiGenerationOverrides? lastOverrides;
Sampling the most recent generate call on this session carried, or null when it inherited the session's own.
LocalAiGenerationOverrides? lastOverrides;