AiResponse class
Response from AI generation
Constructors
- AiResponse({required String text, int? tokenCount, int? generationTimeMs})
-
const
-
AiResponse.fromMap(Map<
String, dynamic> map) -
factory
Properties
- generationTimeMs → int?
-
Generation time in milliseconds
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
The generated text
final
- tokenCount → int?
-
Token count used
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited