countTokensError property
Thrown by countTokens when set. Use LocalAiTokenizerUnavailable to model a host with no tokenizer, or any other error to model a broken channel.
Implementation
Object? countTokensError;
Thrown by countTokens when set. Use LocalAiTokenizerUnavailable to model a host with no tokenizer, or any other error to model a broken channel.
Object? countTokensError;